import { BasicColumn, FormSchema } from '/@/components/Table';
import { h, unref } from 'vue';
import { Tag, Tooltip } from 'ant-design-vue';
import { useLocale } from '/@/locales/useLocale';
import { useI18n } from '/@/hooks/web/useI18n';
import { GetEnum, getEntity } from '/@/api/tigerapi/system';

const { getLocale } = useLocale();
const { t } = useI18n();

export const columns: BasicColumn[] = [
  {
    title: '工单号',
    dataIndex: 'ORDER_NO',
    width: 200,
    sorter: true,
    resizable: true,
  },
  {
    title: '工单描述',
    dataIndex: 'ORDER_DESC',
    width: 200,
    sorter: true,
    resizable: true,
    ifShow: false,
  },
  {
    title: '工单类型',
    dataIndex: 'ORDER_TYPE',
    width: 100,
    sorter: true,
    resizable: true,
    customRender: ({ record }) => {
      let text = '';
      let color = '';
      switch (record.ORDER_TYPE) {
        case 0:
          text = '计划';
          color = '#8a8a8a';
          break;
        case 1:
          text = '标准';
          color = 'green';
          break;
        case 2:
          text = '返工';
          color = 'red';
          break;
        case 3:
          text = '在库改制';
          color = 'blue';
          break;
        case 5:
          text = '委外';
          color = 'yellow';
          break;
        case 6:
          text = '研发';
          color = 'orange';
          break;
        case 7:
          text = '预测';
          color = '#078737';
          break;
        case 8:
          text = '拆卸';
          color = '#e1822c';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: text }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: '工艺状态',
    dataIndex: 'ROUTE_STATUS',
    sorter: true,
    resizable: true,
    customRender: ({ record }) => {
      const status = record.ROUTE_STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '待配置';
          color = '#8a8a8a';
          break;
        case 1:
          text = '已配置';
          color = 'blue';
          break;
        case 2:
          text = '取消';
          color = 'red';
          break;
        case 3:
          text = '已关闭';
          color = '#e1822c';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: text }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: '状态',
    dataIndex: 'STATUS',
    sorter: true,
    resizable: true,
    customRender: ({ record }) => {
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '初始化';
          color = '#8a8a8a';
          break;
        case 1:
          text = '已导入';
          color = 'blue';
          break;
        case 2:
          text = '已下发';
          color = 'green';
          break;
        case 3:
          text = '生产中';
          color = 'blue';
          break;
        case 4:
          text = '已暂停';
          color = 'red';
          break;
        case 5:
          text = '已关闭';
          color = '#e1822c';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: text }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: '计划数量',
    dataIndex: 'PLAN_QTY',
    sorter: true,
    resizable: true,
  },
  {
    title: '工艺路线编码',
    dataIndex: 'ROUTE_CODE',
    sorter: true,
    resizable: true,
  },
  {
    title: '物料编码',
    dataIndex: 'ITEM_CODE',
    sorter: true,
    resizable: true,
  },
  {
    title: '物料类型',
    dataIndex: 'ITEM_TYPE',
    sorter: true,
    resizable: true,
    ifShow: false,
  },
  {
    title: '下发人',
    dataIndex: 'RELEASE_USER',
    sorter: true,
    resizable: true,
  },
  {
    title: '下发时间',
    dataIndex: 'RELEASE_TIME',
    sorter: true,
    resizable: true,
  },
  {
    title: '机型',
    dataIndex: 'ITEM_MODEL',
    sorter: true,
    resizable: true,
    ifShow: false,
  },
  {
    title: '优先级',
    dataIndex: 'PRIORITY',
    sorter: true,
    resizable: true,
  },
  {
    title: '客户编码',
    dataIndex: 'CUST_CODE',
    sorter: true,
    resizable: true,
  },
  {
    title: '工厂',
    dataIndex: 'FACTORY',
    sorter: true,
    resizable: true,
  },
  {
    title: '父工单',
    dataIndex: 'PARENT_ORDER',
    sorter: true,
    resizable: true,
  },
  {
    title: '计划线体',
    dataIndex: 'PLAN_LINE',
    sorter: true,
    resizable: true,
  },
  {
    title: '实际线体',
    dataIndex: 'ACT_LINE',
    sorter: true,
    resizable: true,
  },
  {
    title: '计划开始时间',
    dataIndex: 'PLAN_START_TIME',
    sorter: true,
    resizable: true,
  },
  {
    title: '计划结束时间',
    dataIndex: 'PLAN_END_TIME',
    sorter: true,
    resizable: true,
  },
  {
    title: '实际开始时间',
    dataIndex: 'ACT_START_TIME',
    sorter: true,
    resizable: true,
  },
  {
    title: '实际结束时间',
    dataIndex: 'ACT_END_TIME',
    sorter: true,
    resizable: true,
  },
  {
    title: '创建人',
    dataIndex: 'CREATE_USER',
    sorter: true,
    resizable: true,
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    sorter: true,
    resizable: true,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'ORDER_NO',
    label: '工单号',
    component: 'Input',
    colProps: { span: 8 },
  },

  {
    field: 'STATUS',
    label: '状态',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: GetEnum,
      params: { name: 'BIZ_MES_WO+STATUSs' },
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  },
  {
    field: 'ORDER_TYPE',
    label: '工单类型',
    component: 'ApiSelect',
    colProps: { span: 8 },
    defaultValue: '',
    componentProps: {
      api: GetEnum,
      params: { name: 'BIZ_MES_WO+ORDER_TYPEs' },
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      placeholder: '请选择工单类型',
    },
  },
  {
    field: 'ITEM_CODE',
    label: '产品编码',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: '0',
    component: 'Input',
    label: '1',
    colSlot: 'add',
    colProps: {
      span: 4,
    },
  },
  {
    field: 'TABLE_NAME',
    label: '表名',
    component: 'Input',
    colProps: { span: 8 },
    defaultValue: 'BIZ_MES_WO', ////必需在页面的查询部分加入'TABLE_NAME'字段并赋值表名，这样就可以用通用分页查询
    ifShow: false,
  },
];

//新增组件export const
export const formSchema: FormSchema[] = [
  {
    field: 'ORDER_NO',
    label: '工单号',
    required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'ORDER_DESC',
    label: '工单描述',
    component: 'Input',
    show: false,
    colProps: { span: 24 },
  },
  {
    field: 'ORDER_TYPE',
    label: '工单类型',
    component: 'ApiSelect',
    colProps: { span: 24 },
    defaultValue: 1,
    componentProps: {
      api: GetEnum,
      params: { name: 'BIZ_MES_WO+ORDER_TYPEs' },
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'PLAN_QTY',
    label: '计划数量',
    component: 'Input',
    show: true,
  },
  {
    field: 'STATUS',
    label: '状态',
    component: 'Input',
    show: false,
  },
  {
    field: 'PARENT_ORDER',
    label: '父工单',
    //required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'ITEM_CODE',
    label: '物料编码',
    required: true,
    component: 'Input',
    colProps: { span: 20 },
  },
  {
    field: '0',
    component: 'Input',
    label: '1',
    colSlot: 'addItem',
    colProps: {
      span: 4,
    },
  },
  {
    field: 'ITEM_TYPE',
    label: '物料类型',
    //required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'ITEM_MODEL',
    label: '机型',
    //required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'PRIORITY',
    label: '优先级',
    //required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'CUST_CODE',
    label: '客户编码',
    required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  // {
  //   field: 'FACTORY',
  //   label: '工厂',
  //   required: true,
  //   component: 'ApiSelect',
  //   colProps: { span: 12 },
  //   componentProps: {
  //     api: getEntity,
  //     params: { entityName: 'MES_FACTORY', sqlcmd: ' 1=1 ' },
  //     resultField: 'Data.Items',
  //     labelField: 'FTY_NAME',
  //     valueField: 'FTY_CODE',
  //   },
  // },
  {
    field: 'PLAN_LINE',
    label: '计划线体',
    required: true,
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getEntity,
      params: { entityName: 'MES_LINE', sqlcmd: ' 1=1 ' },
      resultField: 'Data.Items',
      labelField: 'LINE_NAME',
      valueField: 'LINE_CODE',
    },
  },
  {
    field: 'ACT_LINE',
    label: '实际线体',
    // required: true,
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: getEntity,
      params: { entityName: 'MES_LINE', sqlcmd: ' 1=1 ' },
      resultField: 'Data.Items',
      labelField: 'LINE_NAME',
      valueField: 'LINE_CODE',
    },
  },
  {
    field: 'PLAN_START_TIME',
    label: '计划开始时间',
    required: true,
    component: 'DatePicker',
    colProps: { span: 24 },
  },
  {
    field: 'PLAN_END_TIME',
    label: '计划结束时间',
    required: true,
    component: 'DatePicker',
    colProps: { span: 24 },
  },
];
